from enum import Enum


class TerminalColors(Enum):
    BLUE = "\033[94m"
    CYAN = "\033[96m"
    GREEN = "\033[92m"
    WARNING = "\033[93m"
    ERROR = "\033[91m"


class TerminalStyling(Enum):
    HEADER = "\033[95m"
    END_CHARACTER = "\033[0m"
    BOLD = "\033[1m"
    UNDERLINE = "\033[4m"


__all__ = ["TerminalColors", "TerminalStyling"]



from nwon_baseline.typings import BoundingBoxCoordinates, BoundingBoxTuple


def bounding_box_coordinates_from_tuple(box: BoundingBoxTuple):
    """
    The box is expected to be a Tuple with coordinates (x1, y1, x2, y2)
    """

    left, top, right, bottom = box
    return BoundingBoxCoordinates(
        top=top,
        right=right,
        bottom=bottom,
        left=left,
    )


def bounding_box_tuple_from_coordinates(
    box: BoundingBoxCoordinates,
) -> BoundingBoxTuple:
    """
    The box returned is a Tuple with coordinates (x1, y1, x2, y2)
    """

    return BoundingBoxTuple((box.left, box.top, box.right, box.bottom))



import subprocess
from typing import List


def execute_command_and_print(command: List[str]) -> None:
    print("\n".join(execute_command(command)))


def execute_command(command: List[str]) -> List[str]:
    process = subprocess.Popen(
        command,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
        universal_newlines=True,
    )

    if process.stdin:
        process.stdin.write("uname -a\n")
        process.stdin.write("uptime\n")
        process.stdin.close()

    return [line.strip() for line in process.stdout] if process.stdout else []


__all__ = [
    "execute_command",
    "execute_command_and_print",
]



from datetime import datetime

import pytz


def datetime_now() -> datetime:
    """
    Returns the timezone aware current date time.
    """

    return pytz.utc.localize(datetime.now())


def datetime_with_timezone(datetime_to_use: datetime) -> datetime:
    """
    Attaches timezone information to datetime if none is already included
    """

    return (
        datetime_to_use
        if datetime_to_use.tzinfo
        else pytz.utc.localize(datetime_to_use)
    )


__all__ = ["datetime_now", "datetime_with_timezone"]



import ctypes
from collections.abc import Callable, Iterable, Sequence
from ctypes import _CData, _SimpleCData, c_char
from multiprocessing.context import BaseContext
from multiprocessing.synchronize import _LockLike
from typing import Any, Generic, Optional, Protocol, Type, TypeVar, Union, overload
from typing_extensions import Literal

_T = TypeVar("_T")
_CT = TypeVar("_CT", bound=_CData)

@overload
def RawValue(typecode_or_type: Type[_CT], *args: Any) -> _CT: ...
@overload
def RawValue(typecode_or_type: str, *args: Any) -> Any: ...
@overload
def RawArray(typecode_or_type: Type[_CT], size_or_initializer: Union[int, Sequence[Any]]) -> ctypes.Array[_CT]: ...
@overload
def RawArray(typecode_or_type: str, size_or_initializer: Union[int, Sequence[Any]]) -> Any: ...
@overload
def Value(typecode_or_type: Type[_CT], *args: Any, lock: Literal[False], ctx: Optional[BaseContext] = ...) -> _CT: ...
@overload
def Value(
    typecode_or_type: Type[_CT], *args: Any, lock: Union[Literal[True], _LockLike], ctx: Optional[BaseContext] = ...
) -> SynchronizedBase[_CT]: ...
@overload
def Value(
    typecode_or_type: str, *args: Any, lock: Union[Literal[True], _LockLike], ctx: Optional[BaseContext] = ...
) -> SynchronizedBase[Any]: ...
@overload
def Value(
    typecode_or_type: Union[str, Type[_CData]], *args: Any, lock: Union[bool, _LockLike] = ..., ctx: Optional[BaseContext] = ...
) -> Any: ...
@overload
def Array(
    typecode_or_type: Type[_CT],
    size_or_initializer: Union[int, Sequence[Any]],
    *,
    lock: Literal[False],
    ctx: Optional[BaseContext] = ...,
) -> _CT: ...
@overload
def Array(
    typecode_or_type: Type[_CT],
    size_or_initializer: Union[int, Sequence[Any]],
    *,
    lock: Union[Literal[True], _LockLike],
    ctx: Optional[BaseContext] = ...,
) -> SynchronizedArray[_CT]: ...
@overload
def Array(
    typecode_or_type: str,
    size_or_initializer: Union[int, Sequence[Any]],
    *,
    lock: Union[Literal[True], _LockLike],
    ctx: Optional[BaseContext] = ...,
) -> SynchronizedArray[Any]: ...
@overload
def Array(
    typecode_or_type: Union[str, Type[_CData]],
    size_or_initializer: Union[int, Sequence[Any]],
    *,
    lock: Union[bool, _LockLike] = ...,
    ctx: Optional[BaseContext] = ...,
) -> Any: ...
def copy(obj: _CT) -> _CT: ...
@overload
def synchronized(obj: _SimpleCData[_T], lock: Optional[_LockLike] = ..., ctx: Optional[Any] = ...) -> Synchronized[_T]: ...
@overload
def synchronized(obj: ctypes.Array[c_char], lock: Optional[_LockLike] = ..., ctx: Optional[Any] = ...) -> SynchronizedString: ...
@overload
def synchronized(obj: ctypes.Array[_CT], lock: Optional[_LockLike] = ..., ctx: Optional[Any] = ...) -> SynchronizedArray[_CT]: ...
@overload
def synchronized(obj: _CT, lock: Optional[_LockLike] = ..., ctx: Optional[Any] = ...) -> SynchronizedBase[_CT]: ...

class _AcquireFunc(Protocol):
    def __call__(self, block: bool = ..., timeout: Optional[float] = ...) -> bool: ...

class SynchronizedBase(Generic[_CT]):
    acquire: _AcquireFunc = ...
    release: Callable[[], None] = ...
    def __init__(self, obj: Any, lock: Optional[_LockLike] = ..., ctx: Optional[Any] = ...) -> None: ...
    def __reduce__(self) -> tuple[Callable[..., Any], tuple[Any, _LockLike]]: ...
    def get_obj(self) -> _CT: ...
    def get_lock(self) -> _LockLike: ...
    def __enter__(self) -> bool: ...
    def __exit__(self, *args: Any) -> None: ...

class Synchronized(SynchronizedBase[_SimpleCData[_T]], Generic[_T]):
    value: _T

class SynchronizedArray(SynchronizedBase[ctypes.Array[_CT]], Generic[_CT]):
    def __len__(self) -> int: ...
    def __getitem__(self, i: int) -> _CT: ...
    def __setitem__(self, i: int, o: _CT) -> None: ...
    def __getslice__(self, start: int, stop: int) -> list[_CT]: ...
    def __setslice__(self, start: int, stop: int, values: Iterable[_CT]) -> None: ...

class SynchronizedString(SynchronizedArray[c_char]):
    value: bytes
    raw: bytes



from typing import NewType, Tuple

from pydantic import BaseModel

BoundingBoxTuple = NewType("BoundingBoxTuple", Tuple[int, int, int, int])


class BoundingBoxCoordinates(BaseModel):
    top: int
    right: int
    bottom: int
    left: int



from nwon_baseline.print_helper.colored_printing import (
    print_blue,
    print_color,
    print_cyan,
    print_error,
    print_green,
    print_warning,
)

__all__ = [
    "print_blue",
    "print_color",
    "print_cyan",
    "print_error",
    "print_green",
    "print_warning",
]



from nwon_baseline.file_helper.file import (
    file_extension_from_path,
    file_extension_from_url,
    get_file_as_binary,
    get_file_object,
    handle_uploaded_file,
    read_file_as_binary,
    read_file_content,
)

__all__ = [
    "file_extension_from_path",
    "file_extension_from_url",
    "get_file_as_binary",
    "get_file_object",
    "handle_uploaded_file",
    "read_file_as_binary",
    "read_file_content",
]



from datetime import datetime
from typing import Optional

import pytz


def timezone_offset_from_country_code(country_code: str) -> Optional[float]:
    timezones = timezones_from_country_code(country_code)

    if timezones is None:
        return None

    timezone_to_use = pytz.timezone(timezones[0])
    timezone_offset = datetime.now(timezone_to_use).utcoffset()
    return timezone_offset.total_seconds() if timezone_offset else None


def timezones_from_country_code(country_code: str) -> Optional[list[str]]:
    if country_code not in pytz.country_timezones:
        return None

    return pytz.country_timezones[country_code]


__all__ = ["timezone_offset_from_country_code", "timezones_from_country_code"]



from nwon_baseline.image_helper.image import (
    bounding_box_coordinates_from_tuple,
    bounding_box_tuple_from_coordinates,
)

__all__ = [
    "bounding_box_coordinates_from_tuple",
    "bounding_box_tuple_from_coordinates",
]



from datetime import datetime, timedelta
from typing import Tuple

from nwon_baseline.date_helper.datetime import datetime_now


def time_until(date_time: datetime) -> Tuple[int, int, int]:
    """
    Time from now until a given date_time.

    Returned is a Tuple of (days, hours, minutes)
    """

    time_since: timedelta = date_time - datetime_now()
    hours = time_since.seconds // 3600
    minutes = (time_since.seconds // 60) % 60

    return (time_since.days, hours, minutes)


__all__ = ["time_until"]



import threading
from _typeshed import StrPath
from string import Template
from time import struct_time
from types import FrameType, TracebackType
from typing import (
    IO,
    Any,
    Callable,
    Dict,
    Iterable,
    List,
    Mapping,
    MutableMapping,
    Optional,
    Sequence,
    Text,
    Tuple,
    Union,
    overload,
)

_SysExcInfoType = Union[Tuple[type, BaseException, Optional[TracebackType]], Tuple[None, None, None]]
_ExcInfoType = Union[None, bool, _SysExcInfoType]
_ArgsType = Union[Tuple[Any, ...], Mapping[str, Any]]
_FilterType = Union[Filter, Callable[[LogRecord], int]]
_Level = Union[int, Text]

raiseExceptions: bool
logThreads: bool
logMultiprocessing: bool
logProcesses: bool
_srcfile: Optional[str]

def currentframe() -> FrameType: ...

_levelNames: Dict[Union[int, str], Union[str, int]]  # Union[int:str, str:int]

class Filterer(object):
    filters: List[Filter]
    def __init__(self) -> None: ...
    def addFilter(self, filter: _FilterType) -> None: ...
    def removeFilter(self, filter: _FilterType) -> None: ...
    def filter(self, record: LogRecord) -> bool: ...

class Logger(Filterer):
    name: str
    level: int
    parent: Union[Logger, PlaceHolder]
    propagate: bool
    handlers: List[Handler]
    disabled: int
    def __init__(self, name: str, level: _Level = ...) -> None: ...
    def setLevel(self, level: _Level) -> None: ...
    def isEnabledFor(self, level: int) -> bool: ...
    def getEffectiveLevel(self) -> int: ...
    def getChild(self, suffix: str) -> Logger: ...
    def debug(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def info(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def warning(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    warn = warning
    def error(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def critical(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    fatal = critical
    def log(
        self, level: int, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def exception(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def _log(
        self, level: int, msg: Any, args: _ArgsType, exc_info: Optional[_ExcInfoType] = ..., extra: Optional[Dict[str, Any]] = ...
    ) -> None: ...  # undocumented
    def filter(self, record: LogRecord) -> bool: ...
    def addHandler(self, hdlr: Handler) -> None: ...
    def removeHandler(self, hdlr: Handler) -> None: ...
    def findCaller(self) -> Tuple[str, int, str]: ...
    def handle(self, record: LogRecord) -> None: ...
    def makeRecord(
        self,
        name: str,
        level: int,
        fn: str,
        lno: int,
        msg: Any,
        args: _ArgsType,
        exc_info: Optional[_SysExcInfoType],
        func: Optional[str] = ...,
        extra: Optional[Mapping[str, Any]] = ...,
    ) -> LogRecord: ...

CRITICAL: int
FATAL: int
ERROR: int
WARNING: int
WARN: int
INFO: int
DEBUG: int
NOTSET: int

class Handler(Filterer):
    level: int  # undocumented
    formatter: Optional[Formatter]  # undocumented
    lock: Optional[threading.Lock]  # undocumented
    name: Optional[str]  # undocumented
    def __init__(self, level: _Level = ...) -> None: ...
    def createLock(self) -> None: ...
    def acquire(self) -> None: ...
    def release(self) -> None: ...
    def setLevel(self, level: _Level) -> None: ...
    def setFormatter(self, fmt: Formatter) -> None: ...
    def filter(self, record: LogRecord) -> bool: ...
    def flush(self) -> None: ...
    def close(self) -> None: ...
    def handle(self, record: LogRecord) -> None: ...
    def handleError(self, record: LogRecord) -> None: ...
    def format(self, record: LogRecord) -> str: ...
    def emit(self, record: LogRecord) -> None: ...

class Formatter:
    converter: Callable[[Optional[float]], struct_time]
    _fmt: Optional[str]
    datefmt: Optional[str]
    def __init__(self, fmt: Optional[str] = ..., datefmt: Optional[str] = ...) -> None: ...
    def format(self, record: LogRecord) -> str: ...
    def formatTime(self, record: LogRecord, datefmt: Optional[str] = ...) -> str: ...
    def formatException(self, ei: _SysExcInfoType) -> str: ...

class Filter:
    def __init__(self, name: str = ...) -> None: ...
    def filter(self, record: LogRecord) -> bool: ...

class LogRecord:
    args: _ArgsType
    asctime: str
    created: int
    exc_info: Optional[_SysExcInfoType]
    exc_text: Optional[str]
    filename: str
    funcName: str
    levelname: str
    levelno: int
    lineno: int
    module: str
    msecs: int
    message: str
    msg: str
    name: str
    pathname: str
    process: int
    processName: str
    relativeCreated: int
    thread: int
    threadName: str
    def __init__(
        self,
        name: str,
        level: int,
        pathname: str,
        lineno: int,
        msg: Any,
        args: _ArgsType,
        exc_info: Optional[_SysExcInfoType],
        func: Optional[str] = ...,
    ) -> None: ...
    def getMessage(self) -> str: ...

class LoggerAdapter:
    logger: Logger
    extra: Mapping[str, Any]
    def __init__(self, logger: Logger, extra: Mapping[str, Any]) -> None: ...
    def process(self, msg: Any, kwargs: MutableMapping[str, Any]) -> Tuple[Any, MutableMapping[str, Any]]: ...
    def debug(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def info(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def warning(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def error(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def exception(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def critical(
        self, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def log(
        self, level: int, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
    ) -> None: ...
    def isEnabledFor(self, level: int) -> bool: ...

@overload
def getLogger() -> Logger: ...
@overload
def getLogger(name: Union[Text, str]) -> Logger: ...
def getLoggerClass() -> type: ...
def debug(msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any) -> None: ...
def info(msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any) -> None: ...
def warning(msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any) -> None: ...

warn = warning

def error(msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any) -> None: ...
def critical(
    msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
) -> None: ...
def exception(
    msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
) -> None: ...
def log(
    level: int, msg: Any, *args: Any, exc_info: _ExcInfoType = ..., extra: Optional[Dict[str, Any]] = ..., **kwargs: Any
) -> None: ...

fatal = critical

def disable(level: int) -> None: ...
def addLevelName(level: int, levelName: str) -> None: ...
def getLevelName(level: Union[int, str]) -> Any: ...
def makeLogRecord(dict: Mapping[str, Any]) -> LogRecord: ...
@overload
def basicConfig() -> None: ...
@overload
def basicConfig(
    *,
    filename: Optional[str] = ...,
    filemode: str = ...,
    format: str = ...,
    datefmt: Optional[str] = ...,
    level: Optional[_Level] = ...,
    stream: IO[str] = ...,
) -> None: ...
def shutdown(handlerList: Sequence[Any] = ...) -> None: ...  # handlerList is undocumented
def setLoggerClass(klass: type) -> None: ...
def captureWarnings(capture: bool) -> None: ...

class StreamHandler(Handler):
    stream: IO[str]  # undocumented
    def __init__(self, stream: Optional[IO[str]] = ...) -> None: ...

class FileHandler(StreamHandler):
    baseFilename: str  # undocumented
    mode: str  # undocumented
    encoding: Optional[str]  # undocumented
    delay: bool  # undocumented
    def __init__(self, filename: StrPath, mode: str = ..., encoding: Optional[str] = ..., delay: bool = ...) -> None: ...
    def _open(self) -> IO[Any]: ...

class NullHandler(Handler): ...

class PlaceHolder:
    def __init__(self, alogger: Logger) -> None: ...
    def append(self, alogger: Logger) -> None: ...

# Below aren't in module docs but still visible

class RootLogger(Logger):
    def __init__(self, level: int) -> None: ...

root: RootLogger

BASIC_FORMAT: str



import socket
import sys
from types import TracebackType
from typing import Any, BinaryIO, Iterable, List, NoReturn, Optional, Tuple, Type, Union, overload

if sys.version_info >= (3, 8):
    # These are based in socket, maybe move them out into _typeshed.pyi or such
    _Address = Union[Tuple[Any, ...], str]
    _RetAddress = Any
    _WriteBuffer = Union[bytearray, memoryview]
    _CMSG = Tuple[int, int, bytes]
    class TransportSocket:
        def __init__(self, sock: socket.socket) -> None: ...
        def _na(self, what: str) -> None: ...
        @property
        def family(self) -> int: ...
        @property
        def type(self) -> int: ...
        @property
        def proto(self) -> int: ...
        def __getstate__(self) -> NoReturn: ...
        def fileno(self) -> int: ...
        def dup(self) -> socket.socket: ...
        def get_inheritable(self) -> bool: ...
        def shutdown(self, how: int) -> None: ...
        @overload
        def getsockopt(self, level: int, optname: int) -> int: ...
        @overload
        def getsockopt(self, level: int, optname: int, buflen: int) -> bytes: ...
        @overload
        def setsockopt(self, level: int, optname: int, value: Union[int, bytes]) -> None: ...
        @overload
        def setsockopt(self, level: int, optname: int, value: None, optlen: int) -> None: ...
        def getpeername(self) -> _RetAddress: ...
        def getsockname(self) -> _RetAddress: ...
        def getsockbyname(self) -> NoReturn: ...  # This method doesn't exist on socket, yet is passed through?
        def accept(self) -> Tuple[socket.socket, _RetAddress]: ...
        def connect(self, address: Union[_Address, bytes]) -> None: ...
        def connect_ex(self, address: Union[_Address, bytes]) -> int: ...
        def bind(self, address: Union[_Address, bytes]) -> None: ...
        if sys.platform == "win32":
            def ioctl(self, control: int, option: Union[int, Tuple[int, int, int], bool]) -> None: ...
        else:
            def ioctl(self, control: int, option: Union[int, Tuple[int, int, int], bool]) -> NoReturn: ...
        def listen(self, __backlog: int = ...) -> None: ...
        def makefile(self) -> BinaryIO: ...
        def sendfile(self, file: BinaryIO, offset: int = ..., count: Optional[int] = ...) -> int: ...
        def close(self) -> None: ...
        def detach(self) -> int: ...
        if sys.platform == "linux":
            def sendmsg_afalg(
                self, msg: Iterable[bytes] = ..., *, op: int, iv: Any = ..., assoclen: int = ..., flags: int = ...
            ) -> int: ...
        else:
            def sendmsg_afalg(
                self, msg: Iterable[bytes] = ..., *, op: int, iv: Any = ..., assoclen: int = ..., flags: int = ...
            ) -> NoReturn: ...
        def sendmsg(
            self, __buffers: Iterable[bytes], __ancdata: Iterable[_CMSG] = ..., __flags: int = ..., __address: _Address = ...
        ) -> int: ...
        @overload
        def sendto(self, data: bytes, address: _Address) -> int: ...
        @overload
        def sendto(self, data: bytes, flags: int, address: _Address) -> int: ...
        def send(self, data: bytes, flags: int = ...) -> int: ...
        def sendall(self, data: bytes, flags: int = ...) -> None: ...
        def set_inheritable(self, inheritable: bool) -> None: ...
        if sys.platform == "win32":
            def share(self, process_id: int) -> bytes: ...
        else:
            def share(self, process_id: int) -> NoReturn: ...
        def recv_into(self, buffer: _WriteBuffer, nbytes: int = ..., flags: int = ...) -> int: ...
        def recvfrom_into(self, buffer: _WriteBuffer, nbytes: int = ..., flags: int = ...) -> Tuple[int, _RetAddress]: ...
        def recvmsg_into(
            self, __buffers: Iterable[_WriteBuffer], __ancbufsize: int = ..., __flags: int = ...
        ) -> Tuple[int, List[_CMSG], int, Any]: ...
        def recvmsg(self, __bufsize: int, __ancbufsize: int = ..., __flags: int = ...) -> Tuple[bytes, List[_CMSG], int, Any]: ...
        def recvfrom(self, bufsize: int, flags: int = ...) -> Tuple[bytes, _RetAddress]: ...
        def recv(self, bufsize: int, flags: int = ...) -> bytes: ...
        def settimeout(self, value: Optional[float]) -> None: ...
        def gettimeout(self) -> Optional[float]: ...
        def setblocking(self, flag: bool) -> None: ...
        def __enter__(self) -> socket.socket: ...
        def __exit__(
            self, exc_type: Optional[Type[BaseException]], exc_val: Optional[BaseException], exc_tb: Optional[TracebackType]
        ) -> None: ...



from nwon_baseline.typings import TerminalColors, TerminalStyling


def print_green(text: str):
    print_color(text, TerminalColors.GREEN)


def print_blue(text: str):
    print_color(text, TerminalColors.BLUE)


def print_cyan(text: str):
    print_color(text, TerminalColors.CYAN)


def print_warning(text: str):
    print_color(text, TerminalColors.WARNING)


def print_error(text: str):
    print_color(text, TerminalColors.ERROR)


def print_color(text: str, color: "TerminalColors") -> None:
    print(f"{color.value}{text}{TerminalStyling.END_CHARACTER.value}")



from typing import List, Optional

from nwon_baseline.print_helper import print_color
from nwon_baseline.typings.terminal_colors import TerminalColors


def import_data_from_file(
    path: str, split_character: str, expected_column_names: List[str]
) -> Optional[List[List[str]]]:
    """
    Gets data from a file that is separated by some characters and arranged in one dataset per line.

    By defining the column names we now how much data you expect per line and can provide better error messages

    In the process some validation is done on the file
    """

    lines = __lines_from_import_file(path)

    if lines is None:
        return None

    return [
        line
        for index, line in enumerate(__separate_data_in_line(lines, split_character))
        if __validate_data_in_line(line, expected_column_names, split_character, index)
    ]


def __lines_from_import_file(path: str) -> Optional[List[str]]:
    try:
        with open(path, encoding="utf-8") as file:
            file_contents = file.read()
            return file_contents.splitlines()
    except FileNotFoundError as exc:
        print_color(exc.__str__(), TerminalColors.ERROR)
        return None


def __separate_data_in_line(lines: List[str], split_character: str) -> List[List[str]]:
    return [line.split(split_character) for line in lines if split_character in line]


def __validate_data_in_line(
    data_from_line: List[str],
    expected_values: List[str],
    split_character: str,
    index: int,
) -> Optional[List[str]]:
    if data_from_line.__len__() != expected_values.__len__():
        print_color(
            f"Error in Line {index+1}\n{split_character.join(data_from_line)}",
            TerminalColors.ERROR,
        )
        print_color(
            f"Each line should only contain the following {expected_values.__len__()} information separated by a '{split_character}': \n {split_character.join(expected_values)}",
            TerminalColors.WARNING,
        )
        return None

    return data_from_line



import sys
from typing import Any, Iterable, List, Optional, TextIO, Tuple, TypeVar, Union

def split(s: str, comments: bool = ..., posix: bool = ...) -> List[str]: ...

if sys.version_info >= (3, 8):
    def join(split_command: Iterable[str]) -> str: ...

def quote(s: str) -> str: ...

_SLT = TypeVar("_SLT", bound=shlex)

class shlex(Iterable[str]):
    commenters: str
    wordchars: str
    whitespace: str
    escape: str
    quotes: str
    escapedquotes: str
    whitespace_split: bool
    infile: str
    instream: TextIO
    source: str
    debug: int
    lineno: int
    token: str
    eof: str
    punctuation_chars: str
    def __init__(
        self,
        instream: Optional[Union[str, TextIO]] = ...,
        infile: Optional[str] = ...,
        posix: bool = ...,
        punctuation_chars: Union[bool, str] = ...,
    ) -> None: ...
    def get_token(self) -> str: ...
    def push_token(self, tok: str) -> None: ...
    def read_token(self) -> str: ...
    def sourcehook(self, newfile: str) -> Tuple[str, TextIO]: ...
    # TODO argument types
    def push_source(self, newstream: Any, newfile: Any = ...) -> None: ...
    def pop_source(self) -> None: ...
    def error_leader(self, infile: Optional[str] = ..., lineno: Optional[int] = ...) -> None: ...
    def __iter__(self: _SLT) -> _SLT: ...
    def __next__(self) -> str: ...



import sys

from nwon_baseline.print_helper.colored_printing import print_error
from nwon_baseline.typings import VersionChange


def checking_version_argument() -> VersionChange:
    arguments = sys.argv

    version_options = [
        VersionChange.MAJOR.value,
        VersionChange.MINOR.value,
        VersionChange.PATCH.value,
    ]

    if (
        arguments is None
        or arguments.__len__() < 2
        or arguments[1] not in version_options
    ):
        print_error(
            f"Expecting one argument that can be one of: {', '.join(version_options)}",
        )
        sys.exit()

    return VersionChange(arguments[1])



import pathlib
from os.path import join, splitext
from typing import BinaryIO, Optional, TextIO


def file_extension_from_url(image_url: str) -> str:
    """
    Returns the extensions of the file in an url including the do in the beginning.
    E.g. www.test.de/file.jpeg?whatever=what would return .jpg
    """

    url_part = image_url.split("?")
    return splitext(url_part[0])[1]


def file_extension_from_path(path: str) -> str:
    """
    The final component's last suffix, if any.

    This includes the leading period. For example: '.txt'
    """

    return pathlib.Path(path).suffix


def get_file_object(file_path: str) -> Optional[TextIO]:
    with open(file_path, encoding="utf-8") as opened_file:
        return opened_file


def get_file_as_binary(file_path: str) -> Optional[BinaryIO]:
    with open(file_path, "rb") as opened_file:
        return opened_file


def read_file_as_binary(file_path: str) -> Optional[bytes]:
    with open(file_path, "rb") as opened_file:
        return opened_file.read()


def read_file_content(file_path: str) -> Optional[str]:
    with open(file_path, "r", encoding="utf-8") as opened_file:
        return opened_file.read()


def handle_uploaded_file(file, destination_path) -> str:
    destination_path = join(destination_path, file.name)

    with open(destination_path, "wb+") as destination:
        for chunk in file.chunks():
            destination.write(chunk)

    return destination_path



from nwon_baseline.date_helper.country import (
    timezone_offset_from_country_code,
    timezones_from_country_code,
)
from nwon_baseline.date_helper.datetime import datetime_now, datetime_with_timezone
from nwon_baseline.date_helper.time_differences import time_until

__all__ = [
    "timezone_offset_from_country_code",
    "timezones_from_country_code",
    "datetime_now",
    "datetime_with_timezone",
    "time_until",
]



import importlib.abc
import importlib.machinery
import os
import types
from typing import Any, Callable, List, Optional, Union

def module_for_loader(fxn: Callable[..., types.ModuleType]) -> Callable[..., types.ModuleType]: ...
def set_loader(fxn: Callable[..., types.ModuleType]) -> Callable[..., types.ModuleType]: ...
def set_package(fxn: Callable[..., types.ModuleType]) -> Callable[..., types.ModuleType]: ...
def resolve_name(name: str, package: str) -> str: ...

MAGIC_NUMBER: bytes

def cache_from_source(path: str, debug_override: Optional[bool] = ..., *, optimization: Optional[Any] = ...) -> str: ...
def source_from_cache(path: str) -> str: ...
def decode_source(source_bytes: bytes) -> str: ...
def find_spec(name: str, package: Optional[str] = ...) -> Optional[importlib.machinery.ModuleSpec]: ...
def spec_from_loader(
    name: str, loader: Optional[importlib.abc.Loader], *, origin: Optional[str] = ..., is_package: Optional[bool] = ...
) -> Optional[importlib.machinery.ModuleSpec]: ...
def spec_from_file_location(
    name: str,
    location: Optional[Union[str, bytes, os.PathLike[str], os.PathLike[bytes]]] = ...,
    *,
    loader: Optional[importlib.abc.Loader] = ...,
    submodule_search_locations: Optional[List[str]] = ...,
) -> Optional[importlib.machinery.ModuleSpec]: ...
def module_from_spec(spec: importlib.machinery.ModuleSpec) -> types.ModuleType: ...

class LazyLoader(importlib.abc.Loader):
    def __init__(self, loader: importlib.abc.Loader) -> None: ...
    @classmethod
    def factory(cls, loader: importlib.abc.Loader) -> Callable[..., LazyLoader]: ...
    def create_module(self, spec: importlib.machinery.ModuleSpec) -> Optional[types.ModuleType]: ...
    def exec_module(self, module: types.ModuleType) -> None: ...



from nwon_baseline.typings.any_dict import AnyDict
from nwon_baseline.typings.bounding_box import BoundingBoxCoordinates, BoundingBoxTuple
from nwon_baseline.typings.celery_return import CeleryReturn
from nwon_baseline.typings.request_body_format import RequestBodyFormat
from nwon_baseline.typings.terminal_colors import TerminalColors, TerminalStyling
from nwon_baseline.typings.version_change import VersionChange

__all__ = [
    "AnyDict",
    "BoundingBoxCoordinates",
    "BoundingBoxTuple",
    "CeleryReturn",
    "RequestBodyFormat",
    "TerminalColors",
    "TerminalStyling",
    "VersionChange",
]



from _typeshed import AnyPath
from typing import Any, Callable, Dict, Optional, Tuple, TypeVar, Union

def run(statement: str, filename: Optional[str] = ..., sort: Union[str, int] = ...) -> None: ...
def runctx(
    statement: str, globals: Dict[str, Any], locals: Dict[str, Any], filename: Optional[str] = ..., sort: Union[str, int] = ...
) -> None: ...

_SelfT = TypeVar("_SelfT", bound=Profile)
_T = TypeVar("_T")
_Label = Tuple[str, int, str]

class Profile:
    bias: int
    stats: dict[_Label, tuple[int, int, int, int, dict[_Label, tuple[int, int, int, int]]]]  # undocumented
    def __init__(self, timer: Optional[Callable[[], float]] = ..., bias: Optional[int] = ...) -> None: ...
    def set_cmd(self, cmd: str) -> None: ...
    def simulate_call(self, name: str) -> None: ...
    def simulate_cmd_complete(self) -> None: ...
    def print_stats(self, sort: Union[str, int] = ...) -> None: ...
    def dump_stats(self, file: AnyPath) -> None: ...
    def create_stats(self) -> None: ...
    def snapshot_stats(self) -> None: ...
    def run(self: _SelfT, cmd: str) -> _SelfT: ...
    def runctx(self: _SelfT, cmd: str, globals: Dict[str, Any], locals: Dict[str, Any]) -> _SelfT: ...
    def runcall(self, __func: Callable[..., _T], *args: Any, **kw: Any) -> _T: ...
    def calibrate(self, m: int, verbose: int = ...) -> float: ...



from nwon_baseline.directory_helper.directory_content import (
    directory_names_in_directory,
    directory_paths_in_directory,
    file_names_in_directory,
    file_paths_in_directory,
    get_latest_file_in_directory,
)
from nwon_baseline.directory_helper.directory_interactions import (
    clean_directory,
    copy_directory,
    create_pathes,
)

__all__ = [
    "clean_directory",
    "copy_directory",
    "directory_names_in_directory",
    "file_names_in_directory",
    "file_paths_in_directory",
    "get_latest_file_in_directory",
    "create_pathes",
    "directory_paths_in_directory",
]



from nwon_baseline.poetry.checking_version_argument import checking_version_argument
from nwon_baseline.poetry.package_version import update_package_version

__all__ = ["checking_version_argument", "update_package_version"]



from enum import Enum
from typing import List, Type, TypeVar

T = TypeVar("T", bound=Enum)


def enum_value_list(enum_class: Type[T]) -> List[str]:
    """
    Returns a list with all the values in the enum
    """

    return [item.value for item in enum_class]


def enum_value_list_as_string(enum_class: Type[T], separator: str = ", ") -> str:
    """
    Returns a string with all the values of an Enum separated by a separator
    """

    return separator.join(enum_value_list(enum_class))


__all__ = ["enum_value_list", "enum_value_list_as_string"]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nwon_baseline',
 'nwon_baseline.date_helper',
 'nwon_baseline.directory_helper',
 'nwon_baseline.file_helper',
 'nwon_baseline.image_helper',
 'nwon_baseline.import_helper',
 'nwon_baseline.poetry',
 'nwon_baseline.print_helper',
 'nwon_baseline.pydantic',
 'nwon_baseline.shell_helper',
 'nwon_baseline.type_helper',
 'nwon_baseline.typings']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=1.8.2', 'pytz>=2022.1,<2023.0']

entry_points = \
{'console_scripts': ['prepare = scripts.prepare:prepare']}

setup_kwargs = {
    'name': 'nwon-baseline',
    'version': '0.1.26',
    'description': 'Python Code that is used in several projects',
    'long_description': '# NWON Python baseline package\n\nThis package provides some basic python functions that can be used across several projects.\n\nThe dependencies of the project are kept to a minimum in order to prevent version conflicts with other projects.\n\nPackage is meant for internal use at [NWON](https://nwon.de) as breaking changes may occur on version changes. This may change at some point but not for now 😇.\n\n## Development Setup\n\nWe recommend developing using poetry. \n\nThis are the steps to setup the project with a local virtual environment:\n\n1. Tell poetry to create dependencies in a `.venv` folder withing the project: `poetry config virtualenvs.in-project true`\n1. Create a virtual environment using the local python version: `poetry env use $(cat .python-version)`\n1. Install dependencies: `poetry install`\n\n## Prepare Package\n\nAs we want to include types with the package it is not as straight forward as just calling `poetry build` 😥.\n\nWe need to:\n\n1. Clean dist folder\n1. Bump up the version of the package\n1. Build the package\n\nLuckily we provide a script for doing all of this `python scripts/prepare.py patch`. Alternatively you can run the script in a poetry context `poetry run prepare patch`. The argument at the end defines whether you want a `patch`, `minor` or `major` version bump.\n\nThe final zipped data ends up in the `dist` folder.\n\n## Publish Package\n\nBefore publishing the package we need to:\n\n1. Add test PyPi repository: `poetry config repositories.testpypi https://test.pypi.org/legacy/`\n2. Publish the package to the test repository: `poetry publish -r testpypi`\n3. Test package: `pip install --index-url https://test.pypi.org/simple/ nwon_baseline`\n\nIf everything works fine publish the package via `poetry publish`.\n',
    'author': 'Reik Stiebeling',
    'author_email': 'reik.stiebeling@nwon.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://nwon.de',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from os import path

from pydantic import BaseModel

from nwon_baseline.file_helper.file import file_extension_from_path


def save_pydantic_model_instance_as_json(
    pydantic_model: BaseModel, file_path: str
) -> str:
    """
    Saves the Pydantic Model instance as a json file.

    Expects the file_path to end with '.json'.
    If the suffix is not json we take the basename of the file_path and attach .json
    """

    suffix = file_extension_from_path(file_path)

    if suffix != ".json":
        splitted_file_name = path.basename(file_path).split(".")
        directory = path.dirname(file_path)

        if len(splitted_file_name) > 2:
            raise Exception(
                f"The file type of {path.basename(file_path)} needs to be json or it can't contain a dot."
            )
        elif len(splitted_file_name) == 2:
            file_path = path.join(directory, f"{splitted_file_name[0]}.json")

    with open(file_path, "w+", encoding="utf-8") as outfile:
        outfile.write(pydantic_model.json())

    return file_path



from enum import Enum
from typing import Optional, Type, TypeVar

# Generic that can only be an Enum or a sub class of Enum
T = TypeVar("T", bound=Enum)


def enum_type_guard(value: str, enum_class: Type[T]) -> Optional[T]:
    """
    Takes a string and an Enum class or a sub class of Enum and returns the typed value or None.
    """

    return (
        enum_class(value) if value in set(item.value for item in enum_class) else None
    )


__all__ = ["enum_type_guard"]



import os
import shutil
from os import path
from pathlib import Path
from typing import List

from nwon_baseline.directory_helper.directory_content import (
    directory_names_in_directory,
    directory_paths_in_directory,
    file_names_in_directory,
    file_paths_in_directory,
)


def create_pathes(pathes: List[str]) -> None:
    for path_to_create in pathes:
        Path(path_to_create).mkdir(parents=True, exist_ok=True)


def copy_directory(source_directory: str, target_directory: str) -> None:
    if path.exists(target_directory):
        shutil.rmtree(target_directory)

    shutil.copytree(source_directory, target_directory)


def clean_directory(directory: str, recursive: bool = False):
    """
    Cleans all files in a directory. Optionally also deletes all sub
    directories including the containing files
    """

    for file_to_remove in file_paths_in_directory(directory):
        os.remove(file_to_remove)

    if recursive:
        for directory in directory_paths_in_directory(directory):
            shutil.rmtree(directory)



import sys
from _typeshed import OpenBinaryMode, OpenBinaryModeReading, OpenBinaryModeUpdating, OpenBinaryModeWriting, OpenTextMode, StrPath
from io import BufferedRandom, BufferedReader, BufferedWriter, FileIO, TextIOWrapper
from os import PathLike, stat_result
from types import TracebackType
from typing import IO, Any, BinaryIO, Generator, List, Optional, Sequence, Tuple, Type, TypeVar, Union, overload
from typing_extensions import Literal

if sys.version_info >= (3, 9):
    from types import GenericAlias

_P = TypeVar("_P", bound=PurePath)

class PurePath(PathLike[str]):
    parts: Tuple[str, ...]
    drive: str
    root: str
    anchor: str
    name: str
    suffix: str
    suffixes: List[str]
    stem: str
    def __new__(cls: Type[_P], *args: StrPath) -> _P: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other: PurePath) -> bool: ...
    def __le__(self, other: PurePath) -> bool: ...
    def __gt__(self, other: PurePath) -> bool: ...
    def __ge__(self, other: PurePath) -> bool: ...
    def __truediv__(self: _P, key: StrPath) -> _P: ...
    def __rtruediv__(self: _P, key: StrPath) -> _P: ...
    def __bytes__(self) -> bytes: ...
    def as_posix(self) -> str: ...
    def as_uri(self) -> str: ...
    def is_absolute(self) -> bool: ...
    def is_reserved(self) -> bool: ...
    if sys.version_info >= (3, 9):
        def is_relative_to(self, *other: StrPath) -> bool: ...
    def match(self, path_pattern: str) -> bool: ...
    def relative_to(self: _P, *other: StrPath) -> _P: ...
    def with_name(self: _P, name: str) -> _P: ...
    if sys.version_info >= (3, 9):
        def with_stem(self: _P, stem: str) -> _P: ...
    def with_suffix(self: _P, suffix: str) -> _P: ...
    def joinpath(self: _P, *other: StrPath) -> _P: ...
    @property
    def parents(self: _P) -> Sequence[_P]: ...
    @property
    def parent(self: _P) -> _P: ...
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, type: Any) -> GenericAlias: ...

class PurePosixPath(PurePath): ...
class PureWindowsPath(PurePath): ...

class Path(PurePath):
    def __new__(cls: Type[_P], *args: StrPath, **kwargs: Any) -> _P: ...
    def __enter__(self: _P) -> _P: ...
    def __exit__(
        self, exc_type: Optional[Type[BaseException]], exc_value: Optional[BaseException], traceback: Optional[TracebackType]
    ) -> Optional[bool]: ...
    @classmethod
    def cwd(cls: Type[_P]) -> _P: ...
    def stat(self) -> stat_result: ...
    def chmod(self, mode: int) -> None: ...
    def exists(self) -> bool: ...
    def glob(self: _P, pattern: str) -> Generator[_P, None, None]: ...
    def group(self) -> str: ...
    def is_dir(self) -> bool: ...
    def is_file(self) -> bool: ...
    if sys.version_info >= (3, 7):
        def is_mount(self) -> bool: ...
    def is_symlink(self) -> bool: ...
    def is_socket(self) -> bool: ...
    def is_fifo(self) -> bool: ...
    def is_block_device(self) -> bool: ...
    def is_char_device(self) -> bool: ...
    def iterdir(self: _P) -> Generator[_P, None, None]: ...
    def lchmod(self, mode: int) -> None: ...
    def lstat(self) -> stat_result: ...
    def mkdir(self, mode: int = ..., parents: bool = ..., exist_ok: bool = ...) -> None: ...
    # Adapted from builtins.open
    # Text mode: always returns a TextIOWrapper
    @overload
    def open(
        self,
        mode: OpenTextMode = ...,
        buffering: int = ...,
        encoding: Optional[str] = ...,
        errors: Optional[str] = ...,
        newline: Optional[str] = ...,
    ) -> TextIOWrapper: ...
    # Unbuffered binary mode: returns a FileIO
    @overload
    def open(
        self, mode: OpenBinaryMode, buffering: Literal[0], encoding: None = ..., errors: None = ..., newline: None = ...
    ) -> FileIO: ...
    # Buffering is on: return BufferedRandom, BufferedReader, or BufferedWriter
    @overload
    def open(
        self,
        mode: OpenBinaryModeUpdating,
        buffering: Literal[-1, 1] = ...,
        encoding: None = ...,
        errors: None = ...,
        newline: None = ...,
    ) -> BufferedRandom: ...
    @overload
    def open(
        self,
        mode: OpenBinaryModeWriting,
        buffering: Literal[-1, 1] = ...,
        encoding: None = ...,
        errors: None = ...,
        newline: None = ...,
    ) -> BufferedWriter: ...
    @overload
    def open(
        self,
        mode: OpenBinaryModeReading,
        buffering: Literal[-1, 1] = ...,
        encoding: None = ...,
        errors: None = ...,
        newline: None = ...,
    ) -> BufferedReader: ...
    # Buffering cannot be determined: fall back to BinaryIO
    @overload
    def open(
        self, mode: OpenBinaryMode, buffering: int, encoding: None = ..., errors: None = ..., newline: None = ...
    ) -> BinaryIO: ...
    # Fallback if mode is not specified
    @overload
    def open(
        self,
        mode: str,
        buffering: int = ...,
        encoding: Optional[str] = ...,
        errors: Optional[str] = ...,
        newline: Optional[str] = ...,
    ) -> IO[Any]: ...
    def owner(self) -> str: ...
    if sys.version_info >= (3, 9):
        def readlink(self: _P) -> _P: ...
    if sys.version_info >= (3, 8):
        def rename(self: _P, target: Union[str, PurePath]) -> _P: ...
        def replace(self: _P, target: Union[str, PurePath]) -> _P: ...
    else:
        def rename(self, target: Union[str, PurePath]) -> None: ...
        def replace(self, target: Union[str, PurePath]) -> None: ...
    def resolve(self: _P, strict: bool = ...) -> _P: ...
    def rglob(self: _P, pattern: str) -> Generator[_P, None, None]: ...
    def rmdir(self) -> None: ...
    def symlink_to(self, target: Union[str, Path], target_is_directory: bool = ...) -> None: ...
    def touch(self, mode: int = ..., exist_ok: bool = ...) -> None: ...
    if sys.version_info >= (3, 8):
        def unlink(self, missing_ok: bool = ...) -> None: ...
    else:
        def unlink(self) -> None: ...
    @classmethod
    def home(cls: Type[_P]) -> _P: ...
    def absolute(self: _P) -> _P: ...
    def expanduser(self: _P) -> _P: ...
    def read_bytes(self) -> bytes: ...
    def read_text(self, encoding: Optional[str] = ..., errors: Optional[str] = ...) -> str: ...
    def samefile(self, other_path: Union[str, bytes, int, Path]) -> bool: ...
    def write_bytes(self, data: bytes) -> int: ...
    def write_text(self, data: str, encoding: Optional[str] = ..., errors: Optional[str] = ...) -> int: ...
    if sys.version_info >= (3, 8):
        def link_to(self, target: Union[StrPath, bytes]) -> None: ...

class PosixPath(Path, PurePosixPath): ...
class WindowsPath(Path, PureWindowsPath): ...



import glob
import os
from typing import List, Optional

from nwon_baseline.file_helper.file import file_extension_from_path


def file_names_in_directory(path_name: str):
    """
    Returns all file names (not the full path!) in a given directory.

    Directories are filtered out
    """

    return [
        os.path.basename(found_path)
        for found_path in file_paths_in_directory(path_name)
    ]


def file_paths_in_directory(
    path_name: str, filter_extensions: Optional[List[str]] = None
) -> List[str]:
    """
    Returns all file paths in a given directory.

    Directories are filtered out.

    Optionally it is possible to filter for certain file extensions.
    File extensions can be defined with or without a dot in the beginning.
    """

    files_in_directory = [
        found_path
        for found_path in paths_in_directory(path_name)
        if os.path.isfile(found_path)
    ]

    if filter_extensions is None:
        return files_in_directory

    extensions = [
        extension if extension.startswith(".") else f".{extension}"
        for extension in filter_extensions
    ]

    return [
        file
        for file in files_in_directory
        if file_extension_from_path(file) in extensions
    ]


def directory_names_in_directory(path_name: str):
    """
    Returns all directory names (not the full path!) in a given directory.

    Files are filtered out.
    """

    return [
        os.path.basename(found_path)
        for found_path in directory_paths_in_directory(path_name)
    ]


def directory_paths_in_directory(path_name: str):
    """
    Returns all directory paths in a given directory.

    Files are filtered out.
    """

    return [
        found_path
        for found_path in paths_in_directory(path_name)
        if os.path.isdir(found_path)
    ]


def get_latest_file_in_directory(path: str):
    list_of_files = glob.glob(os.path.join(path, "*"))

    if len(list_of_files) > 0:
        latest_file = max(list_of_files, key=os.path.getctime)
        return latest_file

    return None


def paths_in_directory(directory: str) -> List[str]:
    return [os.path.join(directory, found_path) for found_path in os.listdir(directory)]



from nwon_baseline.type_helper.enum_type_guard import enum_type_guard
from nwon_baseline.type_helper.enum_value_list import (
    enum_value_list,
    enum_value_list_as_string,
)

__all__ = [
    "enum_type_guard",
    "enum_value_list",
    "enum_value_list_as_string",
]



from typing import Tuple

from nwon_baseline.shell_helper.execute_command import execute_command
from nwon_baseline.typings.version_change import VersionChange


def update_package_version(version_change: VersionChange) -> str:
    version = __new_version(version_change)
    execute_command(["poetry", "version", version])
    return version


def __package_version() -> Tuple[int, int, int]:
    output = "".join(execute_command(["poetry", "version"]))
    version = output.split(" ")[1].split(".")
    return (int(version[0]), int(version[1]), int(version[2]))


def __new_version(version_change: VersionChange) -> str:
    major, minor, patch = __package_version()

    if version_change.value == VersionChange.MAJOR.value:
        major = major + 1

    if version_change.value == VersionChange.MINOR.value:
        minor = minor + 1

    if version_change.value == VersionChange.PATCH.value:
        patch = patch + 1

    return f"{major}.{minor}.{patch}"


__all__ = ["update_package_version"]
